mod send;
mod receive;

use std::io;
use clap::{Parser, Subcommand};

#[derive(Parser)]
#[command(name = "rperf")]
#[command(about = "A simple CLI for sending and receiving UDP messages", long_about = None)]
struct Cli {
    #[command(subcommand)]
    command: Commands,
}

#[derive(Subcommand)]
enum Commands {
    /// Send a message to a specified host and port
    Send {
        /// The target IP address and port: host:port
        #[arg(long)]
        host: String,

        /// The message to send
        #[arg(short, long)]
        message: String,

        /// Number of times to send
        #[arg(short, long)]
        iters: u32,
    },
    /// Receive a message from a specified host and port
    Receive {
        /// The src IP address and port: host:port
        #[arg(long)]
        host: String,

        /// Number of times to receive
        #[arg(short, long)]
        iters: u32,
    },
}

fn main() -> io::Result<()> {
    let cli = Cli::parse();

    match cli.command {
        Commands::Send { host, message, iters } => {
            println!("Sending message '{}' to {}", message, host);
            send::send(&host, &message, iters)?
        }
        Commands::Receive { host, iters } => {
            println!("Receiving messages from {}", host);
            receive::receive(&host, iters)?
        }
    }

    Ok(())
}
