use std::net::UdpSocket;
use std::io;
use std::time::Instant;

pub fn receive(host: &str, iters: u32) -> io::Result<()> {
    let socket = UdpSocket::bind(host).expect("Failed to bind socket");
    let packet_size = 1080;

    let mut buf = vec![0u8; packet_size];
    let mut total_size: usize = 0;
    let mut start: Option<Instant> = None;

    for i in 0..iters {
        match socket.recv_from(&mut buf) {
            Ok((size, _)) => {
                if start.is_none() {
                    start = Some(Instant::now());
                }
                total_size += size;
                if i % 10000 == 0 {
                    let elapsed = start.unwrap().elapsed().as_secs_f64();
                    let mbps = (total_size * 8) as f64 / 1e6 / elapsed;
                    let pps = 10000.0 / elapsed;
                    println!("{}: Received {} bytes in {} seconds ({} mbps, {} pps)", i, total_size, elapsed, mbps, pps);
                    total_size = 0;
                    start = None;
                }
            },
            Err(e) => eprintln!("Failed to receive message: {}", e),
        }
    }

    Ok(())
}
